@@ -1,10 +1,13 @@
 # pylint: disable=W0201
 """ Handle request for index page """
-from tornado.web import RequestHandler, StaticFileHandler, authenticated
+from tornado.web import RequestHandler, authenticated
 from .access_control import UserMixin
+from .utils.assets_mixin import AssetsMixin
 
 
-class EditorHandler(UserMixin, RequestHandler):  # pylint: disable=W0223
+class EditorHandler(
+    AssetsMixin, UserMixin, RequestHandler
+):  # pylint: disable=W0223
     """ return index page """
 
     def initialize(self, manifest, page):
@@ -29,16 +32,6 @@ class EditorHandler(UserMixin, RequestHandler):  # pylint: disable=W0223
         """ return app resource """
         return self.application.settings["duck_templates"]
 
-    def asset_url(self, path):
-        """ return asset handler versioned url """
-        return StaticFileHandler.make_static_url(
-            {
-                "static_url_prefix": "/edit/assets/",
-                "static_path": self.application.settings["duck_assets"],
-            },
-            path,
-        )
-
     @authenticated
     def get(self):
         """ handle get request """
